'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2010
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'


Imports DotNetNuke.Common.Globals
Imports DotNetNuke.Services.Exceptions
Imports DotNetNuke.Security

Namespace DotNetNuke.Modules.Roadmap

    Partial Public Class Comment
        Inherits Entities.Modules.PortalModuleBase

        Private EnhancementId As Integer = -1
        Private EnhancementCommentId As Integer = -1

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try
                ' get EnhancementId
                If Not Request.QueryString("EnhancementId") Is Nothing Then
                    EnhancementId = Integer.Parse(Request.QueryString("EnhancementId"))
                End If
                ' get EnhancementCommentId
                If Not Request.QueryString("EnhancementCommentId") Is Nothing Then
                    EnhancementCommentId = Integer.Parse(Request.QueryString("EnhancementCommentId"))
                End If

                ' security check
                If EnhancementCommentId <> -1 Then
                    Dim objEnhancementComments As New EnhancementCommentController
                    Dim objEnhancementComment As EnhancementCommentInfo = objEnhancementComments.GetEnhancementComment(EnhancementCommentId, EnhancementId)
                    If IsEditable() = False And objEnhancementComment.UserId <> UserInfo.UserID Then
                        Response.Redirect(NavigateURL("Access Denied"), True)
                    End If
                End If

                ' initialize
                If Page.IsPostBack = False Then
                    BindData()
                End If
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdDelete_Click(ByVal sender As Object, ByVal e As EventArgs) Handles cmdDelete.Click
            Try
                If EnhancementCommentId <> -1 Then
                    Dim objEnhancementComments As New EnhancementCommentController
                    objEnhancementComments.DeleteEnhancementComment(EnhancementCommentId, EnhancementId)
                End If
                Response.Redirect(NavigateURL(), True)
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdCancel_Click(ByVal sender As Object, ByVal e As EventArgs) Handles cmdCancel.Click
            Try
                Response.Redirect(NavigateURL(), True)
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdUpdate_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles cmdUpdate.Click

            Dim objEnhancementComments As New EnhancementCommentController

            ' sanitize input
            Dim strComment As String = SanitizeInput(txtComment.Text, 0)

            If strComment <> "" Then
                If EnhancementCommentId <> -1 Then
                    ' update
                    objEnhancementComments.UpdateEnhancementComment(EnhancementCommentId, EnhancementId, strComment)
                End If
            Else
                objEnhancementComments.DeleteEnhancementComment(EnhancementCommentId, EnhancementId)
            End If

            Response.Redirect(NavigateURL(), True)

        End Sub

        Private Sub BindData()

            Dim objEnhancementComments As New EnhancementCommentController
            Dim objEnhancementComment As EnhancementCommentInfo = objEnhancementComments.GetEnhancementComment(EnhancementCommentId, EnhancementId)

            If Not objEnhancementComment Is Nothing Then
                txtComment.Text = objEnhancementComment.Comment

                cmdUpdate.Text = "Update"
                If IsEditable = False Then
                    cmdDelete.Visible = False
                Else
                    cmdDelete.Attributes.Add("onClick", "javascript:return confirm('Are You Sure You Wish To Delete This Item ?');")
                End If
            End If

        End Sub

        Private Function SanitizeInput(ByVal strValue As String, ByVal intMaxLength As Integer) As String
            Dim objSecurity As New PortalSecurity
            strValue = objSecurity.InputFilter(strValue, PortalSecurity.FilterFlag.NoScripting Or PortalSecurity.FilterFlag.NoAngleBrackets Or PortalSecurity.FilterFlag.NoMarkup)
            If strValue.Length > intMaxLength And intMaxLength <> 0 Then
                strValue = strValue.Substring(0, intMaxLength)
            End If
            Return strValue
        End Function

    End Class

End Namespace

