'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2010
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'

Imports System.Reflection
Imports DotNetNuke.Services.Localization
Imports DotNetNuke.Services.Exceptions
Imports DotNetNuke.Entities.Users
Imports DotNetNuke.Security
Imports DotNetNuke.Common.Globals

Namespace DotNetNuke.Modules.Roadmap

    Partial Public Class Details

        Inherits Entities.Modules.PortalModuleBase

#Region "Private Members"

        Private EnhancementId As Integer = -1
        Private DetailsTemplate As String
        Private CommentsTemplate As String

#End Region

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try

                ' get Enhancementid
                If Not Request.QueryString("EnhancementId") Is Nothing Then
                    EnhancementId = Integer.Parse(Request.QueryString("EnhancementId"))
                End If

                If CType(Settings("detailstemplate"), String) <> "" Then
                    DetailsTemplate = CType(Settings("detailstemplate"), String)
                Else
                    DetailsTemplate = Localization.GetString("DetailsTemplate.Text", LocalResourceFile)
                End If

                If CType(Settings("commentstemplate"), String) <> "" Then
                    CommentsTemplate = CType(Settings("commentstemplate"), String)
                Else
                    CommentsTemplate = Localization.GetString("CommentsTemplate.Text", LocalResourceFile)
                End If

                If Request.IsAuthenticated Then
                    lblCommentsLogin.Visible = False
                    pnlComment.Visible = True
                Else
                    lblCommentsLogin.Visible = True
                    pnlComment.Visible = False
                End If

                If Page.IsPostBack = False Then
                    LoadEnhancement()
                End If

            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try

        End Sub

        Private Sub cmdAdd_Click(ByVal sender As Object, ByVal e As EventArgs) Handles cmdAdd.Click
            Try
                If EnhancementId <> -1 Then
                    Dim objEnhancementComments As New EnhancementCommentController
                    objEnhancementComments.AddEnhancementComment(EnhancementId, SanitizeInput(txtComment.Text, 0), UserId)

                    Dim objEnhancements As New EnhancementController
                    Dim objEnhancement As EnhancementInfo = objEnhancements.GetEnhancement(EnhancementId, ModuleId)
                    If Not objEnhancement Is Nothing Then
                        Dim objUser As UserInfo = UserController.GetUser(PortalId, objEnhancement.UserId, False)
                        ' send email
                        Dim strSendTo As String = PortalSettings.Email
                        If CType(Settings("sendto"), String) <> "" Then
                            strSendTo = CType(Settings("sendto"), String)
                        End If
                        Dim strBody As String = ""
                        strBody += "Dear " & objUser.DisplayName & "," & vbCrLf & vbCrLf
                        strBody += "A Comment Has Been Added To Your Enhancement by " & UserInfo.DisplayName & "." & vbCrLf & vbCrLf
                        strBody += SanitizeInput(txtComment.Text, 0) & vbCrLf & vbCrLf
                        strBody += "You Can View Your Project By Visiting The Following Link:" & vbCrLf
                        strBody += EditUrl("enhancementid", EnhancementId.ToString, "Details") & vbCrLf & vbCrLf
                        strBody += "Sincerely," & vbCrLf & PortalSettings.PortalName
                        DotNetNuke.Services.Mail.Mail.SendMail(PortalSettings.Email, objUser.Email, strSendTo, "Enhancement Comment: " & objEnhancement.Title, strBody, "", "", "", "", "", "")
                    End If
                End If
                Response.Redirect(Request.RawUrl, True)
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub LoadEnhancement()
            Dim strEnhancement As String = DetailsTemplate
            Dim strValue As String = ""

            Dim objEnhancements As New EnhancementController
            Dim objEnhancement As EnhancementInfo = objEnhancements.GetEnhancement(EnhancementId, ModuleId)
            If Not objEnhancement Is Nothing Then
                ' add content to template
                Dim objProperties As ArrayList = Common.Utilities.CBO.GetPropertyInfo(GetType(EnhancementInfo))
                Dim intProperty As Integer
                Dim objPropertyInfo As PropertyInfo
                For intProperty = 0 To objProperties.Count - 1
                    objPropertyInfo = CType(objProperties(intProperty), PropertyInfo)
                    If strEnhancement.IndexOf("[" & objPropertyInfo.Name.ToUpper & "]") <> -1 Then
                        strValue = Server.HtmlDecode(DotNetNuke.Framework.Reflection.GetProperty(GetType(EnhancementInfo), objPropertyInfo.Name, objEnhancement))
                        strEnhancement = strEnhancement.Replace("[" & objPropertyInfo.Name.ToUpper & "]", strValue)
                    End If
                Next intProperty

                ' manage vote
                Dim strVoteURL As String = ""
                If Request.IsAuthenticated Then
                    strVoteURL += "<a href=""" & ModulePath & "Vote.aspx?tabid=" & TabId.ToString & "&enhancementid=" & objEnhancement.EnhancementID.ToString() & """>"
                    strVoteURL += "<img title=""Vote For This Enhancement"" src=""" & ModulePath & "/vote.gif"" alt=""Vote For This Enhancement"" style=""border-width:0px;"" />"
                    strVoteURL += "</a>"
                Else
                    strVoteURL += "<img title=""You Must Login To Vote"" src=""" & ModulePath & "/vote.gif"" alt=""You Must Login To Vote"" style=""border-width:0px;"" />"
                End If
                strEnhancement = strEnhancement.Replace("[VOTE]", strVoteURL)

                ' manage image
                If objEnhancement.URL <> "" Then
                    strEnhancement = strEnhancement.Replace("[IMAGE]", "<br><img src=""" & objEnhancement.URL & """ style=""border-width:0px;"" /><br>")
                Else
                    strEnhancement = strEnhancement.Replace("[IMAGE]", "")
                End If

                lblDetails.Text = strEnhancement

                Dim objEnhancementComments As New EnhancementCommentController
                Dim arrEnhancementComments As ArrayList = objEnhancementComments.GetEnhancementComments(EnhancementId)
                lstComments.DataSource = arrEnhancementComments
                lstComments.DataBind()
            End If

        End Sub

        Protected Sub lstComments_ItemDataBound(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.DataListItemEventArgs) Handles lstComments.ItemDataBound
            Dim strComment As String = CommentsTemplate
            Dim strValue As String = ""

            ' add content to template
            Dim objProperties As ArrayList = Common.Utilities.CBO.GetPropertyInfo(GetType(EnhancementCommentInfo))
            Dim intProperty As Integer
            Dim objPropertyInfo As PropertyInfo
            For intProperty = 0 To objProperties.Count - 1
                objPropertyInfo = CType(objProperties(intProperty), PropertyInfo)
                If strComment.IndexOf("[" & objPropertyInfo.Name.ToUpper & "]") <> -1 Then
                    strValue = Server.HtmlDecode(DataBinder.Eval(e.Item.DataItem, objPropertyInfo.Name).ToString())
                    strComment = strComment.Replace("[" & objPropertyInfo.Name.ToUpper & "]", strValue)
                End If
            Next intProperty

            ' manage user editable
            If IsEditable() = True Or DataBinder.Eval(e.Item.DataItem, "UserID") = UserInfo.UserID Then
                Dim strEdit As String = ""
                strEdit += "<a href=""" & EditUrl("enhancementcommentid", DataBinder.Eval(e.Item.DataItem, "EnhancementCommentID").ToString(), "Comment", "enhancementid=" & EnhancementId.ToString()) & """>"
                strEdit += "<img title=""Edit Comment"" src=""" & Common.Globals.ApplicationPath & "/images/edit.gif"" alt=""Edit Comment"" style=""border-width:0px;"" />"
                strEdit += "</a>"
                strComment = strComment.Replace("[EDIT]", strEdit)
            Else
                strComment = strComment.Replace("[EDIT]", "")
            End If

            ' manage carriage returns
            strComment = strComment.Replace(vbCrLf, "<BR />")

            ' assign the content
            Dim lblComment As Label = CType(e.Item.FindControl("lblComment"), Label)
            lblComment.Text = strComment
        End Sub

        Protected Sub cmdReturn_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles cmdReturn.Click

            Response.Redirect(NavigateURL(), True)

        End Sub

        Private Function SanitizeInput(ByVal strValue As String, ByVal intMaxLength As Integer) As String
            Dim objSecurity As New PortalSecurity
            strValue = objSecurity.InputFilter(strValue, PortalSecurity.FilterFlag.NoScripting Or PortalSecurity.FilterFlag.NoAngleBrackets Or PortalSecurity.FilterFlag.NoMarkup)
            If strValue.Length > intMaxLength And intMaxLength <> 0 Then
                strValue = strValue.Substring(0, intMaxLength)
            End If
            Return strValue
        End Function


    End Class

End Namespace

