'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2010
' by DotNetNuke Corporation
'
' Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated 
' documentation files (the "Software"), to deal in the Software without restriction, including without limitation 
' the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and 
' to permit persons to whom the Software is furnished to do so, subject to the following conditions:
'
' The above copyright notice and this permission notice shall be included in all copies or substantial portions 
' of the Software.
'
' THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED 
' TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL 
' THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF 
' CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
' DEALINGS IN THE SOFTWARE.
'


Imports DotNetNuke.Common.Globals
Imports DotNetNuke.Services.Exceptions
Imports System.Reflection
Imports DotNetNuke.Services.Localization
Imports DotNetNuke.Security
Imports DotNetNuke.UI

Namespace DotNetNuke.Modules.Roadmap

    Partial Public Class Edit

        Inherits Entities.Modules.PortalModuleBase

        Private EnhancementId As Integer = -1
        Private CommentsTemplate As String

        Private Sub Page_Load(ByVal sender As System.Object, ByVal e As System.EventArgs) Handles MyBase.Load
            Try
                ' get Enhancementid
                If Not Request.QueryString("EnhancementId") Is Nothing Then
                    EnhancementId = Integer.Parse(Request.QueryString("EnhancementId"))
                Else
                    If Not cboEnhancement.SelectedItem Is Nothing Then
                        EnhancementId = Integer.Parse(cboEnhancement.SelectedValue)
                    End If
                End If

                If CType(Settings("commentstemplate"), String) <> "" Then
                    CommentsTemplate = CType(Settings("commentstemplate"), String)
                Else
                    CommentsTemplate = Localization.GetString("CommentsTemplate.Text", LocalResourceFile)
                End If

                ' security check
                If EnhancementId <> -1 Then
                    Dim objEnhancements As New EnhancementController
                    Dim objEnhancement As EnhancementInfo = objEnhancements.GetEnhancement(EnhancementId, ModuleId)
                    If IsEditable() = False And objEnhancement.UserId <> UserInfo.UserID Then
                        Response.Redirect(NavigateURL("Access Denied"), True)
                    End If
                End If

                ' initialize
                If Page.IsPostBack = False Then
                    LoadEnhancements()
                    BindData()
                End If
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdDelete_Click(ByVal sender As Object, ByVal e As EventArgs) Handles cmdDelete.Click
            Try
                If EnhancementId <> -1 Then
                    Dim objEnhancements As New EnhancementController
                    objEnhancements.DeleteEnhancement(EnhancementId, ModuleId)
                End If
                Response.Redirect(NavigateURL(), True)
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdCancel_Click(ByVal sender As Object, ByVal e As EventArgs) Handles cmdCancel.Click
            Try
                Response.Redirect(NavigateURL(), True)
            Catch exc As Exception
                ProcessModuleLoadException(Me, exc)
            End Try
        End Sub

        Private Sub cmdUpdate_Click(ByVal sender As Object, ByVal e As System.EventArgs) Handles cmdUpdate.Click

            Dim objEnhancements As New EnhancementController

            Dim blnAuthorized As Boolean = False
            Dim strScheduled As String = ""
            Dim strDelivered As String = ""

            ' sanitize input
            Dim strTitle As String = SanitizeInput(txtTitle.Text, 50)
            Dim strURL As String = SanitizeInput(txtURL.Text, 125)
            If strURL <> "" Then
                strURL = AddHTTP(strURL)
            End If
            Dim strDescription As String = SanitizeInput(txtDescription.Text, 1000)
            Dim strProblem As String = SanitizeInput(txtProblem.Text, 0)
            Dim strRationale As String = SanitizeInput(txtRationale.Text, 0)
            Dim strSolution As String = SanitizeInput(txtSolution.Text, 0)
            Dim strImpact As String = SanitizeInput(txtImpact.Text, 0)
            Dim strRisk As String = SanitizeInput(txtRisk.Text, 0)

            If strTitle <> "" And strDescription <> "" Then
                If EnhancementId = -1 Then
                    ' add new
                    If rowAuthorized.Visible = True Then
                        blnAuthorized = chkAuthorized.Checked
                        strScheduled = txtScheduled.Text
                        strDelivered = txtDelivered.Text
                    End If

                    ' add enhancement
                    EnhancementId = objEnhancements.AddEnhancement(ModuleId, strTitle, strURL, strDescription, strProblem, strRationale, strSolution, strImpact, strRisk, blnAuthorized, strScheduled, strDelivered, UserId)

                    LoadEnhancements()
                    cboEnhancement.Items.FindByValue(EnhancementId.ToString).Selected = True
                    BindData()
                Else
                    ' update
                    Dim objEnhancement As EnhancementInfo = objEnhancements.GetEnhancement(EnhancementId, ModuleId)
                    If rowAuthorized.Visible = True Then
                        blnAuthorized = chkAuthorized.Checked
                        strScheduled = txtScheduled.Text
                        strDelivered = txtDelivered.Text
                    Else
                        blnAuthorized = objEnhancement.Authorized
                        strScheduled = objEnhancement.Scheduled
                        strDelivered = objEnhancement.Delivered
                    End If
                    objEnhancements.UpdateEnhancement(EnhancementId, ModuleId, strTitle, strURL, strDescription, strProblem, strRationale, strSolution, strImpact, strRisk, blnAuthorized, strScheduled, strDelivered)
                End If

                ' send email
                Dim strSendTo As String = PortalSettings.Email
                If CType(Settings("sendto"), String) <> "" Then
                    strSendTo = CType(Settings("sendto"), String)
                End If
                'TODO: localize the email being sent
                Dim strBody As String = ""
                strBody += "Dear " & UserInfo.DisplayName & "," & vbCrLf & vbCrLf
                strBody += "Your Enhancement Has Been Successfully Submitted." & vbCrLf & vbCrLf
                strBody += strDescription & vbCrLf & vbCrLf
                strBody += "You Can Manage Your Enhancement In The Future By Visiting The Following Link:" & vbCrLf
                strBody += EditUrl("enhancementid", EnhancementId.ToString) & vbCrLf & vbCrLf
                strBody += "Sincerely," & vbCrLf & PortalSettings.PortalName
                DotNetNuke.Services.Mail.Mail.SendMail(PortalSettings.Email, UserInfo.Email, strSendTo, "Enhancement: " & strTitle, strBody, "", "", "", "", "", "")

                Response.Redirect(NavigateURL(), True)

            Else ' fields required
                Skins.Skin.AddModuleMessage(Me, Localization.GetString("Required.Text", LocalResourceFile), Skins.Controls.ModuleMessage.ModuleMessageType.YellowWarning)
            End If

        End Sub

        Protected Sub cboEnhancement_SelectedIndexChanged(ByVal sender As Object, ByVal e As System.EventArgs) Handles cboEnhancement.SelectedIndexChanged
            EnhancementId = Integer.Parse(cboEnhancement.SelectedValue)
            BindData()
        End Sub

        Private Sub BindData()

            Dim objEnhancements As New EnhancementController
            Dim objEnhancement As EnhancementInfo = objEnhancements.GetEnhancement(EnhancementId, ModuleId)

            If Not objEnhancement Is Nothing Then
                txtTitle.Text = objEnhancement.Title.ToString
                txtURL.Text = objEnhancement.URL.ToString
                txtDescription.Text = objEnhancement.Description.ToString
                chkAuthorized.Checked = objEnhancement.Authorized
                txtScheduled.Text = objEnhancement.Scheduled
                txtDelivered.Text = objEnhancement.Delivered

                txtProblem.Text = objEnhancement.Problem.ToString
                txtRationale.Text = objEnhancement.Rationale.ToString
                txtSolution.Text = objEnhancement.Solution.ToString
                txtImpact.Text = objEnhancement.Impact.ToString
                txtRisk.Text = objEnhancement.Risk.ToString

                lblCreatedDate.Text = objEnhancement.CreatedDate.ToString
                lblVotes.Text = objEnhancement.Votes.ToString
                lblComments.Text = objEnhancement.Comments.ToString

                Dim objEnhancementComments As New EnhancementCommentController
                Dim arrEnhancementComments As ArrayList = objEnhancementComments.GetEnhancementComments(EnhancementId)
                lstComments.DataSource = arrEnhancementComments
                lstComments.DataBind()

                cmdUpdate.Text = "Update"
                If EditMode() = False Then
                    txtURL.Enabled = False
                    rowAuthorized.Visible = False
                    rowScheduled.Visible = False
                    rowDelivered.Visible = False
                    cmdDelete.Visible = False
                Else
                    txtURL.Enabled = True
                    'TODO: localize the delete options
                    cmdDelete.Attributes.Add("onClick", "javascript:return confirm('Are You Sure You Wish To Delete This Item ?');")
                End If
            Else
                txtTitle.Text = ""
                txtURL.Text = ""
                txtURL.Enabled = True
                txtDescription.Text = ""
                rowAuthorized.Visible = False
                rowScheduled.Visible = False
                rowDelivered.Visible = False
                txtProblem.Text = ""
                txtRationale.Text = ""
                txtSolution.Text = ""
                txtImpact.Text = ""
                txtRisk.Text = ""
                pnlSummary.Visible = False
                'TODO: localize
                cmdUpdate.Text = "Create"
                cmdDelete.Visible = False
            End If

        End Sub

        Private Sub LoadEnhancements()
            Dim objEnhancements As New EnhancementController
            If IsEditable() Then
                Dim intTotalRecords As Integer
                cboEnhancement.DataSource = objEnhancements.GetEnhancements(ModuleId, True, 10000, 0, 0, intTotalRecords)
            Else
                cboEnhancement.DataSource = objEnhancements.GetEnhancementsByUser(ModuleId, UserId)
            End If
            cboEnhancement.DataBind()
            cboEnhancement.Items.Insert(0, New ListItem(Localization.GetString("Create.Text", LocalResourceFile), "-1"))
        End Sub

        Private Function SanitizeInput(ByVal strValue As String, ByVal intMaxLength As Integer) As String
            If IsEditable() = False Then
                Dim objSecurity As New PortalSecurity
                strValue = objSecurity.InputFilter(strValue, PortalSecurity.FilterFlag.NoScripting Or PortalSecurity.FilterFlag.NoAngleBrackets Or PortalSecurity.FilterFlag.NoMarkup)
                If strValue.Length > intMaxLength And intMaxLength <> 0 Then
                    strValue = strValue.Substring(0, intMaxLength)
                End If
            End If
            Return strValue
        End Function

        Protected Sub lstComments_ItemDataBound(ByVal sender As Object, ByVal e As System.Web.UI.WebControls.DataListItemEventArgs) Handles lstComments.ItemDataBound
            Dim strComment As String = CommentsTemplate
            Dim strValue As String = ""

            ' add content to template
            Dim objProperties As ArrayList = Common.Utilities.CBO.GetPropertyInfo(GetType(EnhancementCommentInfo))
            Dim intProperty As Integer
            Dim objPropertyInfo As PropertyInfo
            For intProperty = 0 To objProperties.Count - 1
                objPropertyInfo = CType(objProperties(intProperty), PropertyInfo)
                If strComment.IndexOf("[" & objPropertyInfo.Name.ToUpper & "]") <> -1 Then
                    strValue = Server.HtmlDecode(DataBinder.Eval(e.Item.DataItem, objPropertyInfo.Name).ToString())
                    strComment = strComment.Replace("[" & objPropertyInfo.Name.ToUpper & "]", strValue)
                End If
            Next intProperty

            ' manage user editable
            If IsEditable() = True Or DataBinder.Eval(e.Item.DataItem, "UserID") = UserInfo.UserID Then
                Dim strEdit As String = ""
                strEdit += "<a href=""" & EditUrl("enhancementcommentid", DataBinder.Eval(e.Item.DataItem, "EnhancementCommentID").ToString(), "Comment", "enhancementid=" & EnhancementId.ToString()) & """>"
                strEdit += "<img title=""Edit Comment"" src=""" & Common.Globals.ApplicationPath & "/images/edit.gif"" alt=""Edit Comment"" style=""border-width:0px;"" />"
                strEdit += "</a>"
                strComment = strComment.Replace("[EDIT]", strEdit)
            Else
                strComment = strComment.Replace("[EDIT]", "")
            End If

            ' manage carriage returns
            strComment = strComment.Replace(vbCrLf, "<BR />")

            ' assign the content
            Dim lblComment As Label = CType(e.Item.FindControl("lblComment"), Label)
            lblComment.Text = strComment
        End Sub
    End Class

End Namespace

