'
' DotNetNuke - http://www.dotnetnuke.com
' Copyright (c) 2002-2007
' by DotNetNuke Corporation
'

Imports System
Imports System.Data
Imports System.Data.SqlClient
Imports Microsoft.ApplicationBlocks.Data
Imports DotNetNuke
Imports DotNetNuke.Common.Utilities

Namespace DotNetNuke.Modules.Roadmap

    Public Class SqlDataProvider

        Inherits DataProvider

#Region "Private Members"

        Private Const ProviderType As String = "data"

        Private _providerConfiguration As Framework.Providers.ProviderConfiguration = Framework.Providers.ProviderConfiguration.GetProviderConfiguration(ProviderType)
        Private _connectionString As String
        Private _providerPath As String
        Private _objectQualifier As String
        Private _databaseOwner As String

#End Region

#Region "Constructors"

        Public Sub New()

            ' Read the configuration specific information for this provider
            Dim objProvider As Framework.Providers.Provider = CType(_providerConfiguration.Providers(_providerConfiguration.DefaultProvider), Framework.Providers.Provider)

            ' Read the attributes for this provider
            _connectionString = Config.GetConnectionString()

            _providerPath = objProvider.Attributes("providerPath")

            _objectQualifier = objProvider.Attributes("objectQualifier")
            If _objectQualifier <> "" And _objectQualifier.EndsWith("_") = False Then
                _objectQualifier += "_"
            End If

            _databaseOwner = objProvider.Attributes("databaseOwner")
            If _databaseOwner <> "" And _databaseOwner.EndsWith(".") = False Then
                _databaseOwner += "."
            End If

        End Sub

#End Region

#Region "Properties"

        Public ReadOnly Property ConnectionString() As String
            Get
                Return _connectionString
            End Get
        End Property

        Public ReadOnly Property ProviderPath() As String
            Get
                Return _providerPath
            End Get
        End Property

        Public ReadOnly Property ObjectQualifier() As String
            Get
                Return _objectQualifier
            End Get
        End Property

        Public ReadOnly Property DatabaseOwner() As String
            Get
                Return _databaseOwner
            End Get
        End Property

#End Region

#Region "Public Methods"

        ' general
        Private Function GetNull(ByVal Field As Object) As Object
            Return Null.GetNull(Field, DBNull.Value)
        End Function

        Public Overrides Function GetEnhancements(ByVal ModuleId As Integer, ByVal IsAdmin As Boolean, ByVal PageSize As Integer, ByVal PageIndex As Integer, ByVal Filter As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancements", ModuleId, IsAdmin, PageSize, PageIndex, Filter), IDataReader)
        End Function
        Public Overrides Function GetEnhancementsByUser(ByVal ModuleId As Integer, ByVal UserId As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancementsByUser", ModuleId, UserID), IDataReader)
        End Function
        Public Overrides Function GetEnhancement(ByVal EnhancementID As Integer, ByVal ModuleID As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancement", EnhancementID, ModuleID), IDataReader)
        End Function
        Public Overrides Sub DeleteEnhancement(ByVal EnhancementID As Integer, ByVal ModuleID As Integer)
            SqlHelper.ExecuteNonQuery(ConnectionString, DatabaseOwner & ObjectQualifier & "DeleteEnhancement", EnhancementID, ModuleID)
        End Sub
        Public Overrides Function AddEnhancement(ByVal ModuleId As Integer, ByVal Title As String, ByVal URL As String, ByVal Description As String, ByVal Problem As String, ByVal Rationale As String, ByVal Solution As String, ByVal Impact As String, ByVal Risk As String, ByVal Authorized As Boolean, ByVal Scheduled As String, ByVal Delivered As String, ByVal UserId As Integer) As Integer
            Return CType(SqlHelper.ExecuteScalar(ConnectionString, DatabaseOwner & ObjectQualifier & "AddEnhancement", ModuleId, Title, URL, Description, Problem, Rationale, Solution, Impact, Risk, Authorized, Scheduled, Delivered, UserId), Integer)
        End Function
        Public Overrides Sub UpdateEnhancement(ByVal EnhancementId As Integer, ByVal ModuleId As Integer, ByVal Title As String, ByVal URL As String, ByVal Description As String, ByVal Problem As String, ByVal Rationale As String, ByVal Solution As String, ByVal Impact As String, ByVal Risk As String, ByVal Authorized As Boolean, ByVal Scheduled As String, ByVal Delivered As String)
            SqlHelper.ExecuteScalar(ConnectionString, DatabaseOwner & ObjectQualifier & "UpdateEnhancement", EnhancementId, ModuleId, Title, URL, Description, Problem, Rationale, Solution, Impact, Risk, Authorized, Scheduled, Delivered)
        End Sub

        Public Overrides Function GetEnhancementVote(ByVal EnhancementId As Integer, ByVal UserId As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancementVote", EnhancementId, UserId), IDataReader)
        End Function
        Public Overrides Sub AddEnhancementVote(ByVal EnhancementId As Integer, ByVal UserId As Integer)
            SqlHelper.ExecuteNonQuery(ConnectionString, DatabaseOwner & ObjectQualifier & "AddEnhancementVote", EnhancementId, UserId)
        End Sub

        Public Overrides Function GetEnhancementComments(ByVal EnhancementId As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancementComments", EnhancementId), IDataReader)
        End Function
        Public Overrides Function GetEnhancementComment(ByVal EnhancementCommentId As Integer, ByVal EnhancementId As Integer) As IDataReader
            Return CType(SqlHelper.ExecuteReader(ConnectionString, DatabaseOwner & ObjectQualifier & "GetEnhancementComment", EnhancementCommentId, EnhancementId), IDataReader)
        End Function
        Public Overrides Sub DeleteEnhancementComment(ByVal EnhancementCommentId As Integer, ByVal EnhancementId As Integer)
            SqlHelper.ExecuteNonQuery(ConnectionString, DatabaseOwner & ObjectQualifier & "DeleteEnhancementComment", EnhancementCommentId, EnhancementId)
        End Sub
        Public Overrides Sub AddEnhancementComment(ByVal EnhancementId As Integer, ByVal Comment As String, ByVal UserId As Integer)
            SqlHelper.ExecuteNonQuery(ConnectionString, DatabaseOwner & ObjectQualifier & "AddEnhancementComment", EnhancementId, Comment, UserId)
        End Sub
        Public Overrides Sub UpdateEnhancementComment(ByVal EnhancementCommentId As Integer, ByVal EnhancementId As Integer, ByVal Comment As String)
            SqlHelper.ExecuteNonQuery(ConnectionString, DatabaseOwner & ObjectQualifier & "UpdateEnhancementComment", EnhancementCommentId, EnhancementId, Comment)
        End Sub

#End Region

    End Class

End Namespace
